# -*- mode: python; coding: utf-8 -*-

import os, re

VERSION = '0.20100717'

SETUP    = '_setup.test'
TEARDOWN = '_teardown.test'

# FIXME: fichero de configuración .atheist
EXCLUDE_DIRS = ['.svn', '.hg']
EXCLUDE_FILES = [SETUP, TEARDOWN]

abort = False

INCLUDE_RE = re.compile(r"""include\("([\./\w\d]+)"\)\s*$""")


#task status
FAIL =    False   # Failed
OK =      True    # Success
NOEXEC =  2       # Never executed
ERROR =   3       # The task itself produced an unexpected error
UNKNOWN = 4
TODO    = 5
mild_FAIL = 6


ATHEIST_BASE = os.path.join(os.environ['HOME'], '.atheist')
ATHEIST_TMP =  '/tmp/atheist'
ATHEIST_CFG =  os.path.join(ATHEIST_BASE, 'config')
ATHEIST_LOG =  os.path.join(ATHEIST_BASE, 'log')
